@@ -42,6 +42,7 @@ import digitalio
 from PIL import Image
 import numpy
 from recordclass import recordclass
+from displayio.colorconverter import ColorConverter
 
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_Blinka_displayio.git"
@@ -53,8 +54,9 @@ BACKLIGHT_IN_OUT = 1
 BACKLIGHT_PWM = 2
 
 # pylint: disable=unnecessary-pass, unused-argument
-
 # pylint: disable=too-many-instance-attributes
+
+
 class Display:
     """This initializes a display and connects it into CircuitPython. Unlike other objects
     in CircuitPython, Display objects live until ``displayio.release_displays()`` is called.
@@ -152,12 +154,23 @@ class Display:
         self._refresh_thread = None
         if self._auto_refresh:
             self.auto_refresh = True
+        self._colorconverter = ColorConverter()
 
         self._backlight_type = None
         if backlight_pin is not None:
-            self._backlight_type = BACKLIGHT_IN_OUT
-            self._backlight = digitalio.DigitalInOut(backlight_pin)
-            self._backlight.switch_to_output()
+            try:
+                from pulseio import PWMOut  # pylint: disable=import-outside-toplevel
+
+                # 100Hz looks decent and doesn't keep the CPU too busy
+                self._backlight = PWMOut(backlight_pin, frequency=100, duty_cycle=0)
+                self._backlight_type = BACKLIGHT_PWM
+            except ImportError:
+                # PWMOut not implemented on this platform
+                pass
+            if self._backlight_type is None:
+                self._backlight_type = BACKLIGHT_IN_OUT
+                self._backlight = digitalio.DigitalInOut(backlight_pin)
+                self._backlight.switch_to_output()
             self.brightness = brightness
 
     # pylint: enable=too-many-locals
@@ -322,7 +335,11 @@ class Display:
 
     def fill_row(self, y, buffer):
         """Extract the pixels from a single row"""
-        pass
+        for x in range(0, self._width):
+            _rgb_565 = self._colorconverter.convert(self._buffer.getpixel((x, y)))
+            buffer[x * 2] = (_rgb_565 >> 8) & 0xFF
+            buffer[x * 2 + 1] = _rgb_565 & 0xFF
+        return buffer
 
     @property
     def auto_refresh(self):
@@ -357,8 +374,10 @@ class Display:
             self._brightness = value
             if self._backlight_type == BACKLIGHT_IN_OUT:
                 self._backlight.value = round(self._brightness)
-            # PWM not currently implemented
-            # Command-based brightness not implemented
+            elif self._backlight_type == BACKLIGHT_PWM:
+                self._backlight.duty_cycle = self._brightness * 65535
+            elif self._brightness_command is not None:
+                self._write(self._brightness_command, round(value * 255))
         else:
             raise ValueError("Brightness must be between 0.0 and 1.0")
 
